@@ -86,16 +86,10 @@ define!({
         AtRule(AtRule),
     }
 
-    pub struct Unit {
-        pub span: Span,
-        pub value: JsWord,
-        pub raw: JsWord,
-    }
-
     pub enum Value {
         SimpleBlock(SimpleBlock),
 
-        Unit(UnitValue),
+        Dimension(Dimension),
 
         Number(Number),
 
@@ -156,10 +150,10 @@ define!({
         pub raw: JsWord,
     }
 
-    pub struct UnitValue {
+    pub struct Dimension {
         pub span: Span,
         pub value: Number,
-        pub unit: Unit,
+        pub unit: Ident,
     }
 
     pub struct Percent {
@@ -548,7 +542,7 @@ define!({
 
     pub enum MediaFeatureValue {
         Number(Number),
-        Dimension(UnitValue),
+        Dimension(Dimension),
         Ident(Ident),
         Ratio(Ratio),
     }
